% ---------------------------------------------------------------------
% dphi0 = func_dphi0(spline_model_logrho, rmax, G, dx)
%     
%     dphi0 = 4 pi G / r²  \int_0^r s² \rho(s) ds
% using an interval with step dx from 0 to rmax.
% ---------------------------------------------------------------------
%
% [input]   spline_model_logrho = the splines for log(\rho)
% [input]               rmax    = the end point
% [input]               G       = gravity constant
% [input]               dx      = discretization step
% [output]            dphi0     = output values, from 0 to Rmax. with 0 in dphi0(1)
%
% ---------------------------------------------------------------------
function dphi0=func_dphi0(spline_model_logrho,rmax,G,dx)


   myx = [0:dx:rmax(1)-dx  rmax] ; % make sure rmax is here
   nx  = length(myx);
   
   % compute the utilities in all points
   locval_rho = exp( ppval(spline_model_logrho,myx)  );
   d = zeros(nx-1,1); 
   for ix=1:nx-1 % compute for all points
     d(ix)  = myx(ix+1) - myx(ix) ;
   end 
   % ---------------------------------

   dphi0    = zeros(1,nx);
   for ix=1:nx-1
     dphi0(ix+1) = dphi0(ix) + d(ix)/2.0 * ...
                   (locval_rho(ix+1)*myx(ix+1).^2 + locval_rho(ix)*myx(ix).^2);
   end
   
   for ix=2:nx
     dphi0(ix) = 4.0*pi*G./(myx(ix).^2) .* dphi0(ix);
   end 

   return

end 
